// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
.change-form {
  #content-main {
    @extend .container-fluid;

    > form {
      @extend %admin-form;
    }
  }

  .object-tools {
    @extend .pl-0;
    @extend .m-2;
    float: right;
    list-style-type: none;

    .historylink {
      &::before {
        content: '\f017';
      }
    }

    .viewsitelink {
      &::before {
        content: '\f26c';
      }
    }
  }
}

.spinner-overlay {
  align-items: center;
  background: $spinner-overlay-bg;
  bottom: 0;
  color: $spinner-overlay-fg;
  display: flex;
  height: 100%;
  justify-content: center;
  left: 0;
  position: fixed;
  right: 0;
  text-align: center;
  top: 0;
  width: 100%;
  z-index: 100;

  p {
    font-size: 3rem;
    font-weight: bold;
  }
}
